From f6ee107eb8024014b7792e0e4b97e16f05ce7d00 Mon Sep 17 00:00:00 2001
From: Marlon Schumacher <schumacher@hfm-karlsruhe.de>
Date: Fri, 14 Mar 2025 22:17:28 +0100
Subject: [PATCH] feat: add Testpatch in Max for Grove UR

---
 render.cpp |   21 ++++++++++++++++-----
 1 files changed, 16 insertions(+), 5 deletions(-)

diff --git a/ultrasonic-bela/render.cpp b/render.cpp
similarity index 85%
rename from ultrasonic-bela/render.cpp
rename to render.cpp
index bda9e40..dc2dec2 100644
--- a/ultrasonic-bela/render.cpp
+++ b/render.cpp
@@ -14,8 +14,8 @@
 
 Ultrasonic sensors can detect distances to a high degree of accuracy, even
 in many conditions where infrared sensors would not be suitable (e.g.: when natural
-light is a problem.
-For this example we used the [HC-SR04](https://cdn.sparkfun.com/datasheets/Sensors/Proximity/HCSR04.pdf).
+light is a problem. For this example we used the [Grove Ultrasonic Ranger]
+(https://wiki.seeedstudio.com/Grove-Ultrasonic_Ranger/).
 
 After it receives a short pulse (> 10us) at its TRIGGER input, the module outputs from the
 ECHO output a pulse whose length is proportional to the distance of the object that is in
@@ -49,10 +49,12 @@
 #include <stdlib.h>
 #include <libraries/Scope/Scope.h>
 #include <libraries/PulseIn/PulseIn.h>
+#include <libraries/OscSender/OscSender.h>
 
 PulseIn pulseIn;
 Scope scope;
-int gTriggerInterval = 2646; // how often to send out a trigger. 2646 samples are 60ms
+int sensorFreq = 10; // freq in Hz for polling value and sending OSC messages
+int gTriggerInterval = 44100 / sensorFreq; // how often to send out a trigger. 2646 samples are 60ms
 int gMinPulseLength = 7; //to avoid spurious readings
 float gRescale = 58; // taken from the datasheet
 unsigned int gTrigDigitalOutPin = 7; //channel to be connected to the module's TRIGGER pin - check the pin diagram in the IDE
@@ -60,8 +62,15 @@
 int gTriggerCount = 0;
 int gPrintfCount = 0;
 
+OscSender oscSender;
+int localPort = 7562;
+const char* remoteIp = "127.0.0.1";
+int remotePort = 57120;
+
 bool setup(BelaContext *context, void *userData)
 {
+	// osc sender setup
+	oscSender.setup(remotePort, remoteIp);
 	// Set the mode of digital pins
 	// pinMode(context, 0, gTrigDigitalOutPin, OUTPUT); // writing to TRIGGER pin
 	// pinMode(context, 0, gEchoDigitalInPin, INPUT); // reading from ECHO pin
@@ -101,9 +110,11 @@
 			// rescaling according to the datasheet
 			distance = duration / gRescale;
 		}
+
 		static int count = 0;
-		if(count > 5000){ // we do not want to print the value every time we read it
-			rt_printf("pulseLength: %d, distance: %fcm\n", pulseLength, distance);
+		if(count > gTriggerInterval){ // we do not want to print the value every time we read it
+			//rt_printf("pulseLength: %d, distance: %fcm\n", pulseLength, distance);
+			oscSender.newMessage("/distance").add(distance).send();
 			count = 0;
 		}
 		++count;

--
Gitblit v1.9.1